@@ -1,8 +1,9 @@
+use super::handle_connection;
 use crate::error::Result;
-use crate::events::event::Event;
 use crate::events::event_handler::EventHandler;
 use crate::ipc::context::Context;
 use crate::ipc::stream_emitter::StreamEmitter;
+use std::sync::Arc;
 use tokio::net::TcpStream;
 
 /// The IPC Client to connect to an IPC Server.
@@ -15,21 +16,20 @@ pub struct IPCClient {
 impl IPCClient {
     /// Connects to a given address and returns an emitter for events to that address.
     /// Invoked by [IPCBuilder::build_client](crate::builder::IPCBuilder::build_client)
-    pub async fn connect(self, address: &str) -> Result<StreamEmitter> {
+    pub async fn connect(self, address: &str) -> Result<Context> {
         let stream = TcpStream::connect(address).await?;
-        let (mut read_half, write_half) = stream.into_split();
+        let (read_half, write_half) = stream.into_split();
         let emitter = StreamEmitter::new(write_half);
         let ctx = Context::new(StreamEmitter::clone(&emitter));
-        let handler = self.handler;
+        let handler = Arc::new(self.handler);
 
-        tokio::spawn(async move {
-            while let Ok(event) = Event::from_async_read(&mut read_half).await {
-                if let Err(e) = handler.handle_event(&ctx, event).await {
-                    log::error!("Failed to handle event: {:?}", e);
-                }
+        tokio::spawn({
+            let ctx = Context::clone(&ctx);
+            async move {
+                handle_connection(handler, read_half, ctx).await;
             }
         });
 
-        Ok(emitter)
+        Ok(ctx)
     }
 }
